# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import inspect
from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
import warnings

from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1, grpc_helpers_async, operations_v1
from google.api_core import retry_async as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.auth.transport.grpc import SslCredentials  # type: ignore
from google.cloud.location import locations_pb2  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
import grpc  # type: ignore
from grpc.experimental import aio  # type: ignore

from google.cloud.gdchardwaremanagement_v1alpha.types import resources, service

from .base import DEFAULT_CLIENT_INFO, GDCHardwareManagementTransport
from .grpc import GDCHardwareManagementGrpcTransport


class GDCHardwareManagementGrpcAsyncIOTransport(GDCHardwareManagementTransport):
    """gRPC AsyncIO backend transport for GDCHardwareManagement.

    The GDC Hardware Management service.

    This class defines the same methods as the primary client, so the
    primary client can load the underlying transport implementation
    and call it.

    It sends protocol buffers over the wire using gRPC (which is built on
    top of HTTP/2); the ``grpcio`` package must be installed.
    """

    _grpc_channel: aio.Channel
    _stubs: Dict[str, Callable] = {}

    @classmethod
    def create_channel(
        cls,
        host: str = "gdchardwaremanagement.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        **kwargs,
    ) -> aio.Channel:
        """Create and return a gRPC AsyncIO channel object.
        Args:
            host (Optional[str]): The host for the channel to use.
            credentials (Optional[~.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                service. These are only used when credentials are not specified and
                are passed to :func:`google.auth.default`.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            kwargs (Optional[dict]): Keyword arguments, which are passed to the
                channel creation.
        Returns:
            aio.Channel: A gRPC AsyncIO channel object.
        """

        return grpc_helpers_async.create_channel(
            host,
            credentials=credentials,
            credentials_file=credentials_file,
            quota_project_id=quota_project_id,
            default_scopes=cls.AUTH_SCOPES,
            scopes=scopes,
            default_host=cls.DEFAULT_HOST,
            **kwargs,
        )

    def __init__(
        self,
        *,
        host: str = "gdchardwaremanagement.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        channel: Optional[Union[aio.Channel, Callable[..., aio.Channel]]] = None,
        api_mtls_endpoint: Optional[str] = None,
        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'gdchardwaremanagement.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is ignored if a ``channel`` instance is provided.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if a ``channel`` instance is provided.
            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                service. These are only used when credentials are not specified and
                are passed to :func:`google.auth.default`.
            channel (Optional[Union[aio.Channel, Callable[..., aio.Channel]]]):
                A ``Channel`` instance through which to make calls, or a Callable
                that constructs and returns one. If set to None, ``self.create_channel``
                is used to create the channel. If a Callable is given, it will be called
                with the same arguments as used in ``self.create_channel``.
            api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                If provided, it overrides the ``host`` argument and tries to create
                a mutual TLS channel with client SSL credentials from
                ``client_cert_source`` or application default SSL credentials.
            client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                Deprecated. A callback to provide client SSL certificate bytes and
                private key bytes, both in PEM format. It is ignored if
                ``api_mtls_endpoint`` is None.
            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
                for the grpc channel. It is ignored if a ``channel`` instance is provided.
            client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                A callback to provide client certificate bytes and private key bytes,
                both in PEM format. It is used to configure a mutual TLS channel. It is
                ignored if a ``channel`` instance or ``ssl_channel_credentials`` is provided.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
              creation failed for any reason.
          google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
              and ``credentials_file`` are passed.
        """
        self._grpc_channel = None
        self._ssl_channel_credentials = ssl_channel_credentials
        self._stubs: Dict[str, Callable] = {}
        self._operations_client: Optional[operations_v1.OperationsAsyncClient] = None

        if api_mtls_endpoint:
            warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
        if client_cert_source:
            warnings.warn("client_cert_source is deprecated", DeprecationWarning)

        if isinstance(channel, aio.Channel):
            # Ignore credentials if a channel was passed.
            credentials = None
            self._ignore_credentials = True
            # If a channel was explicitly provided, set it.
            self._grpc_channel = channel
            self._ssl_channel_credentials = None
        else:
            if api_mtls_endpoint:
                host = api_mtls_endpoint

                # Create SSL credentials with client_cert_source or application
                # default SSL credentials.
                if client_cert_source:
                    cert, key = client_cert_source()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )
                else:
                    self._ssl_channel_credentials = SslCredentials().ssl_credentials

            else:
                if client_cert_source_for_mtls and not ssl_channel_credentials:
                    cert, key = client_cert_source_for_mtls()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )

        # The base transport sets the host, credentials and scopes
        super().__init__(
            host=host,
            credentials=credentials,
            credentials_file=credentials_file,
            scopes=scopes,
            quota_project_id=quota_project_id,
            client_info=client_info,
            always_use_jwt_access=always_use_jwt_access,
            api_audience=api_audience,
        )

        if not self._grpc_channel:
            # initialize with the provided callable or the default channel
            channel_init = channel or type(self).create_channel
            self._grpc_channel = channel_init(
                self._host,
                # use the credentials which are saved
                credentials=self._credentials,
                # Set ``credentials_file`` to ``None`` here as
                # the credentials that we saved earlier should be used.
                credentials_file=None,
                scopes=self._scopes,
                ssl_credentials=self._ssl_channel_credentials,
                quota_project_id=quota_project_id,
                options=[
                    ("grpc.max_send_message_length", -1),
                    ("grpc.max_receive_message_length", -1),
                ],
            )

        # Wrap messages. This must be done after self._grpc_channel exists
        self._wrap_with_kind = (
            "kind" in inspect.signature(gapic_v1.method_async.wrap_method).parameters
        )
        self._prep_wrapped_messages(client_info)

    @property
    def grpc_channel(self) -> aio.Channel:
        """Create the channel designed to connect to this service.

        This property caches on the instance; repeated calls return
        the same channel.
        """
        # Return the channel from cache.
        return self._grpc_channel

    @property
    def operations_client(self) -> operations_v1.OperationsAsyncClient:
        """Create the client designed to process long-running operations.

        This property caches on the instance; repeated calls return the same
        client.
        """
        # Quick check: Only create a new client if we do not already have one.
        if self._operations_client is None:
            self._operations_client = operations_v1.OperationsAsyncClient(
                self.grpc_channel
            )

        # Return the client from cache.
        return self._operations_client

    @property
    def list_orders(
        self,
    ) -> Callable[[service.ListOrdersRequest], Awaitable[service.ListOrdersResponse]]:
        r"""Return a callable for the list orders method over gRPC.

        Lists orders in a given project and location.

        Returns:
            Callable[[~.ListOrdersRequest],
                    Awaitable[~.ListOrdersResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_orders" not in self._stubs:
            self._stubs["list_orders"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/ListOrders",
                request_serializer=service.ListOrdersRequest.serialize,
                response_deserializer=service.ListOrdersResponse.deserialize,
            )
        return self._stubs["list_orders"]

    @property
    def get_order(
        self,
    ) -> Callable[[service.GetOrderRequest], Awaitable[resources.Order]]:
        r"""Return a callable for the get order method over gRPC.

        Gets details of an order.

        Returns:
            Callable[[~.GetOrderRequest],
                    Awaitable[~.Order]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_order" not in self._stubs:
            self._stubs["get_order"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/GetOrder",
                request_serializer=service.GetOrderRequest.serialize,
                response_deserializer=resources.Order.deserialize,
            )
        return self._stubs["get_order"]

    @property
    def create_order(
        self,
    ) -> Callable[[service.CreateOrderRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the create order method over gRPC.

        Creates a new order in a given project and location.

        Returns:
            Callable[[~.CreateOrderRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_order" not in self._stubs:
            self._stubs["create_order"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/CreateOrder",
                request_serializer=service.CreateOrderRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_order"]

    @property
    def update_order(
        self,
    ) -> Callable[[service.UpdateOrderRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the update order method over gRPC.

        Updates the parameters of an order.

        Returns:
            Callable[[~.UpdateOrderRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_order" not in self._stubs:
            self._stubs["update_order"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/UpdateOrder",
                request_serializer=service.UpdateOrderRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_order"]

    @property
    def delete_order(
        self,
    ) -> Callable[[service.DeleteOrderRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the delete order method over gRPC.

        Deletes an order.

        Returns:
            Callable[[~.DeleteOrderRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_order" not in self._stubs:
            self._stubs["delete_order"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/DeleteOrder",
                request_serializer=service.DeleteOrderRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["delete_order"]

    @property
    def submit_order(
        self,
    ) -> Callable[[service.SubmitOrderRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the submit order method over gRPC.

        Submits an order.

        Returns:
            Callable[[~.SubmitOrderRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "submit_order" not in self._stubs:
            self._stubs["submit_order"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/SubmitOrder",
                request_serializer=service.SubmitOrderRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["submit_order"]

    @property
    def list_sites(
        self,
    ) -> Callable[[service.ListSitesRequest], Awaitable[service.ListSitesResponse]]:
        r"""Return a callable for the list sites method over gRPC.

        Lists sites in a given project and location.

        Returns:
            Callable[[~.ListSitesRequest],
                    Awaitable[~.ListSitesResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_sites" not in self._stubs:
            self._stubs["list_sites"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/ListSites",
                request_serializer=service.ListSitesRequest.serialize,
                response_deserializer=service.ListSitesResponse.deserialize,
            )
        return self._stubs["list_sites"]

    @property
    def get_site(self) -> Callable[[service.GetSiteRequest], Awaitable[resources.Site]]:
        r"""Return a callable for the get site method over gRPC.

        Gets details of a site.

        Returns:
            Callable[[~.GetSiteRequest],
                    Awaitable[~.Site]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_site" not in self._stubs:
            self._stubs["get_site"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/GetSite",
                request_serializer=service.GetSiteRequest.serialize,
                response_deserializer=resources.Site.deserialize,
            )
        return self._stubs["get_site"]

    @property
    def create_site(
        self,
    ) -> Callable[[service.CreateSiteRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the create site method over gRPC.

        Creates a new site in a given project and location.

        Returns:
            Callable[[~.CreateSiteRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_site" not in self._stubs:
            self._stubs["create_site"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/CreateSite",
                request_serializer=service.CreateSiteRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_site"]

    @property
    def update_site(
        self,
    ) -> Callable[[service.UpdateSiteRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the update site method over gRPC.

        Updates the parameters of a site.

        Returns:
            Callable[[~.UpdateSiteRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_site" not in self._stubs:
            self._stubs["update_site"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/UpdateSite",
                request_serializer=service.UpdateSiteRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_site"]

    @property
    def delete_site(
        self,
    ) -> Callable[[service.DeleteSiteRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the delete site method over gRPC.

        Deletes a site.

        Returns:
            Callable[[~.DeleteSiteRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_site" not in self._stubs:
            self._stubs["delete_site"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/DeleteSite",
                request_serializer=service.DeleteSiteRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["delete_site"]

    @property
    def list_hardware_groups(
        self,
    ) -> Callable[
        [service.ListHardwareGroupsRequest],
        Awaitable[service.ListHardwareGroupsResponse],
    ]:
        r"""Return a callable for the list hardware groups method over gRPC.

        Lists hardware groups in a given order.

        Returns:
            Callable[[~.ListHardwareGroupsRequest],
                    Awaitable[~.ListHardwareGroupsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_hardware_groups" not in self._stubs:
            self._stubs["list_hardware_groups"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/ListHardwareGroups",
                request_serializer=service.ListHardwareGroupsRequest.serialize,
                response_deserializer=service.ListHardwareGroupsResponse.deserialize,
            )
        return self._stubs["list_hardware_groups"]

    @property
    def get_hardware_group(
        self,
    ) -> Callable[
        [service.GetHardwareGroupRequest], Awaitable[resources.HardwareGroup]
    ]:
        r"""Return a callable for the get hardware group method over gRPC.

        Gets details of a hardware group.

        Returns:
            Callable[[~.GetHardwareGroupRequest],
                    Awaitable[~.HardwareGroup]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_hardware_group" not in self._stubs:
            self._stubs["get_hardware_group"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/GetHardwareGroup",
                request_serializer=service.GetHardwareGroupRequest.serialize,
                response_deserializer=resources.HardwareGroup.deserialize,
            )
        return self._stubs["get_hardware_group"]

    @property
    def create_hardware_group(
        self,
    ) -> Callable[
        [service.CreateHardwareGroupRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the create hardware group method over gRPC.

        Creates a new hardware group in a given order.

        Returns:
            Callable[[~.CreateHardwareGroupRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_hardware_group" not in self._stubs:
            self._stubs["create_hardware_group"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/CreateHardwareGroup",
                request_serializer=service.CreateHardwareGroupRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_hardware_group"]

    @property
    def update_hardware_group(
        self,
    ) -> Callable[
        [service.UpdateHardwareGroupRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the update hardware group method over gRPC.

        Updates the parameters of a hardware group.

        Returns:
            Callable[[~.UpdateHardwareGroupRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_hardware_group" not in self._stubs:
            self._stubs["update_hardware_group"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/UpdateHardwareGroup",
                request_serializer=service.UpdateHardwareGroupRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_hardware_group"]

    @property
    def delete_hardware_group(
        self,
    ) -> Callable[
        [service.DeleteHardwareGroupRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the delete hardware group method over gRPC.

        Deletes a hardware group.

        Returns:
            Callable[[~.DeleteHardwareGroupRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_hardware_group" not in self._stubs:
            self._stubs["delete_hardware_group"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/DeleteHardwareGroup",
                request_serializer=service.DeleteHardwareGroupRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["delete_hardware_group"]

    @property
    def list_hardware(
        self,
    ) -> Callable[
        [service.ListHardwareRequest], Awaitable[service.ListHardwareResponse]
    ]:
        r"""Return a callable for the list hardware method over gRPC.

        Lists hardware in a given project and location.

        Returns:
            Callable[[~.ListHardwareRequest],
                    Awaitable[~.ListHardwareResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_hardware" not in self._stubs:
            self._stubs["list_hardware"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/ListHardware",
                request_serializer=service.ListHardwareRequest.serialize,
                response_deserializer=service.ListHardwareResponse.deserialize,
            )
        return self._stubs["list_hardware"]

    @property
    def get_hardware(
        self,
    ) -> Callable[[service.GetHardwareRequest], Awaitable[resources.Hardware]]:
        r"""Return a callable for the get hardware method over gRPC.

        Gets hardware details.

        Returns:
            Callable[[~.GetHardwareRequest],
                    Awaitable[~.Hardware]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_hardware" not in self._stubs:
            self._stubs["get_hardware"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/GetHardware",
                request_serializer=service.GetHardwareRequest.serialize,
                response_deserializer=resources.Hardware.deserialize,
            )
        return self._stubs["get_hardware"]

    @property
    def create_hardware(
        self,
    ) -> Callable[[service.CreateHardwareRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the create hardware method over gRPC.

        Creates new hardware in a given project and location.

        Returns:
            Callable[[~.CreateHardwareRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_hardware" not in self._stubs:
            self._stubs["create_hardware"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/CreateHardware",
                request_serializer=service.CreateHardwareRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_hardware"]

    @property
    def update_hardware(
        self,
    ) -> Callable[[service.UpdateHardwareRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the update hardware method over gRPC.

        Updates hardware parameters.

        Returns:
            Callable[[~.UpdateHardwareRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_hardware" not in self._stubs:
            self._stubs["update_hardware"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/UpdateHardware",
                request_serializer=service.UpdateHardwareRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_hardware"]

    @property
    def delete_hardware(
        self,
    ) -> Callable[[service.DeleteHardwareRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the delete hardware method over gRPC.

        Deletes hardware.

        Returns:
            Callable[[~.DeleteHardwareRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_hardware" not in self._stubs:
            self._stubs["delete_hardware"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/DeleteHardware",
                request_serializer=service.DeleteHardwareRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["delete_hardware"]

    @property
    def list_comments(
        self,
    ) -> Callable[
        [service.ListCommentsRequest], Awaitable[service.ListCommentsResponse]
    ]:
        r"""Return a callable for the list comments method over gRPC.

        Lists the comments on an order.

        Returns:
            Callable[[~.ListCommentsRequest],
                    Awaitable[~.ListCommentsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_comments" not in self._stubs:
            self._stubs["list_comments"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/ListComments",
                request_serializer=service.ListCommentsRequest.serialize,
                response_deserializer=service.ListCommentsResponse.deserialize,
            )
        return self._stubs["list_comments"]

    @property
    def get_comment(
        self,
    ) -> Callable[[service.GetCommentRequest], Awaitable[resources.Comment]]:
        r"""Return a callable for the get comment method over gRPC.

        Gets the content of a comment.

        Returns:
            Callable[[~.GetCommentRequest],
                    Awaitable[~.Comment]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_comment" not in self._stubs:
            self._stubs["get_comment"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/GetComment",
                request_serializer=service.GetCommentRequest.serialize,
                response_deserializer=resources.Comment.deserialize,
            )
        return self._stubs["get_comment"]

    @property
    def create_comment(
        self,
    ) -> Callable[[service.CreateCommentRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the create comment method over gRPC.

        Creates a new comment on an order.

        Returns:
            Callable[[~.CreateCommentRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_comment" not in self._stubs:
            self._stubs["create_comment"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/CreateComment",
                request_serializer=service.CreateCommentRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_comment"]

    @property
    def record_action_on_comment(
        self,
    ) -> Callable[[service.RecordActionOnCommentRequest], Awaitable[resources.Comment]]:
        r"""Return a callable for the record action on comment method over gRPC.

        Record Action on a Comment. If the Action specified
        in the request is READ, the viewed time in the comment
        is set to the time the request was received. If the
        comment is already marked as read, subsequent calls will
        be ignored. If the Action is UNREAD, the viewed time is
        cleared from the comment.

        Returns:
            Callable[[~.RecordActionOnCommentRequest],
                    Awaitable[~.Comment]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "record_action_on_comment" not in self._stubs:
            self._stubs["record_action_on_comment"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/RecordActionOnComment",
                request_serializer=service.RecordActionOnCommentRequest.serialize,
                response_deserializer=resources.Comment.deserialize,
            )
        return self._stubs["record_action_on_comment"]

    @property
    def list_change_log_entries(
        self,
    ) -> Callable[
        [service.ListChangeLogEntriesRequest],
        Awaitable[service.ListChangeLogEntriesResponse],
    ]:
        r"""Return a callable for the list change log entries method over gRPC.

        Lists the changes made to an order.

        Returns:
            Callable[[~.ListChangeLogEntriesRequest],
                    Awaitable[~.ListChangeLogEntriesResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_change_log_entries" not in self._stubs:
            self._stubs["list_change_log_entries"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/ListChangeLogEntries",
                request_serializer=service.ListChangeLogEntriesRequest.serialize,
                response_deserializer=service.ListChangeLogEntriesResponse.deserialize,
            )
        return self._stubs["list_change_log_entries"]

    @property
    def get_change_log_entry(
        self,
    ) -> Callable[
        [service.GetChangeLogEntryRequest], Awaitable[resources.ChangeLogEntry]
    ]:
        r"""Return a callable for the get change log entry method over gRPC.

        Gets details of a change to an order.

        Returns:
            Callable[[~.GetChangeLogEntryRequest],
                    Awaitable[~.ChangeLogEntry]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_change_log_entry" not in self._stubs:
            self._stubs["get_change_log_entry"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/GetChangeLogEntry",
                request_serializer=service.GetChangeLogEntryRequest.serialize,
                response_deserializer=resources.ChangeLogEntry.deserialize,
            )
        return self._stubs["get_change_log_entry"]

    @property
    def list_skus(
        self,
    ) -> Callable[[service.ListSkusRequest], Awaitable[service.ListSkusResponse]]:
        r"""Return a callable for the list skus method over gRPC.

        Lists SKUs for a given project and location.

        Returns:
            Callable[[~.ListSkusRequest],
                    Awaitable[~.ListSkusResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_skus" not in self._stubs:
            self._stubs["list_skus"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/ListSkus",
                request_serializer=service.ListSkusRequest.serialize,
                response_deserializer=service.ListSkusResponse.deserialize,
            )
        return self._stubs["list_skus"]

    @property
    def get_sku(self) -> Callable[[service.GetSkuRequest], Awaitable[resources.Sku]]:
        r"""Return a callable for the get sku method over gRPC.

        Gets details of an SKU.

        Returns:
            Callable[[~.GetSkuRequest],
                    Awaitable[~.Sku]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_sku" not in self._stubs:
            self._stubs["get_sku"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/GetSku",
                request_serializer=service.GetSkuRequest.serialize,
                response_deserializer=resources.Sku.deserialize,
            )
        return self._stubs["get_sku"]

    @property
    def list_zones(
        self,
    ) -> Callable[[service.ListZonesRequest], Awaitable[service.ListZonesResponse]]:
        r"""Return a callable for the list zones method over gRPC.

        Lists zones in a given project and location.

        Returns:
            Callable[[~.ListZonesRequest],
                    Awaitable[~.ListZonesResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_zones" not in self._stubs:
            self._stubs["list_zones"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/ListZones",
                request_serializer=service.ListZonesRequest.serialize,
                response_deserializer=service.ListZonesResponse.deserialize,
            )
        return self._stubs["list_zones"]

    @property
    def get_zone(self) -> Callable[[service.GetZoneRequest], Awaitable[resources.Zone]]:
        r"""Return a callable for the get zone method over gRPC.

        Gets details of a zone.

        Returns:
            Callable[[~.GetZoneRequest],
                    Awaitable[~.Zone]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_zone" not in self._stubs:
            self._stubs["get_zone"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/GetZone",
                request_serializer=service.GetZoneRequest.serialize,
                response_deserializer=resources.Zone.deserialize,
            )
        return self._stubs["get_zone"]

    @property
    def create_zone(
        self,
    ) -> Callable[[service.CreateZoneRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the create zone method over gRPC.

        Creates a new zone in a given project and location.

        Returns:
            Callable[[~.CreateZoneRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_zone" not in self._stubs:
            self._stubs["create_zone"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/CreateZone",
                request_serializer=service.CreateZoneRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_zone"]

    @property
    def update_zone(
        self,
    ) -> Callable[[service.UpdateZoneRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the update zone method over gRPC.

        Updates the parameters of a zone.

        Returns:
            Callable[[~.UpdateZoneRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_zone" not in self._stubs:
            self._stubs["update_zone"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/UpdateZone",
                request_serializer=service.UpdateZoneRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_zone"]

    @property
    def delete_zone(
        self,
    ) -> Callable[[service.DeleteZoneRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the delete zone method over gRPC.

        Deletes a zone.

        Returns:
            Callable[[~.DeleteZoneRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_zone" not in self._stubs:
            self._stubs["delete_zone"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/DeleteZone",
                request_serializer=service.DeleteZoneRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["delete_zone"]

    @property
    def signal_zone_state(
        self,
    ) -> Callable[
        [service.SignalZoneStateRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the signal zone state method over gRPC.

        Signals the state of a zone.

        Returns:
            Callable[[~.SignalZoneStateRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "signal_zone_state" not in self._stubs:
            self._stubs["signal_zone_state"] = self.grpc_channel.unary_unary(
                "/google.cloud.gdchardwaremanagement.v1alpha.GDCHardwareManagement/SignalZoneState",
                request_serializer=service.SignalZoneStateRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["signal_zone_state"]

    def _prep_wrapped_messages(self, client_info):
        """Precompute the wrapped methods, overriding the base class method to use async wrappers."""
        self._wrapped_methods = {
            self.list_orders: self._wrap_method(
                self.list_orders,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_order: self._wrap_method(
                self.get_order,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.create_order: self._wrap_method(
                self.create_order,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.update_order: self._wrap_method(
                self.update_order,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_order: self._wrap_method(
                self.delete_order,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.submit_order: self._wrap_method(
                self.submit_order,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_sites: self._wrap_method(
                self.list_sites,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_site: self._wrap_method(
                self.get_site,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.create_site: self._wrap_method(
                self.create_site,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.update_site: self._wrap_method(
                self.update_site,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_site: self._wrap_method(
                self.delete_site,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_hardware_groups: self._wrap_method(
                self.list_hardware_groups,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_hardware_group: self._wrap_method(
                self.get_hardware_group,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.create_hardware_group: self._wrap_method(
                self.create_hardware_group,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.update_hardware_group: self._wrap_method(
                self.update_hardware_group,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_hardware_group: self._wrap_method(
                self.delete_hardware_group,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_hardware: self._wrap_method(
                self.list_hardware,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_hardware: self._wrap_method(
                self.get_hardware,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.create_hardware: self._wrap_method(
                self.create_hardware,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.update_hardware: self._wrap_method(
                self.update_hardware,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_hardware: self._wrap_method(
                self.delete_hardware,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_comments: self._wrap_method(
                self.list_comments,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_comment: self._wrap_method(
                self.get_comment,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.create_comment: self._wrap_method(
                self.create_comment,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.record_action_on_comment: self._wrap_method(
                self.record_action_on_comment,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_change_log_entries: self._wrap_method(
                self.list_change_log_entries,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_change_log_entry: self._wrap_method(
                self.get_change_log_entry,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_skus: self._wrap_method(
                self.list_skus,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_sku: self._wrap_method(
                self.get_sku,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_zones: self._wrap_method(
                self.list_zones,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_zone: self._wrap_method(
                self.get_zone,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.create_zone: self._wrap_method(
                self.create_zone,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.update_zone: self._wrap_method(
                self.update_zone,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.delete_zone: self._wrap_method(
                self.delete_zone,
                default_retry=retries.AsyncRetry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.signal_zone_state: self._wrap_method(
                self.signal_zone_state,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_location: self._wrap_method(
                self.get_location,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_locations: self._wrap_method(
                self.list_locations,
                default_timeout=None,
                client_info=client_info,
            ),
            self.cancel_operation: self._wrap_method(
                self.cancel_operation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_operation: self._wrap_method(
                self.delete_operation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_operation: self._wrap_method(
                self.get_operation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_operations: self._wrap_method(
                self.list_operations,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def _wrap_method(self, func, *args, **kwargs):
        if self._wrap_with_kind:  # pragma: NO COVER
            kwargs["kind"] = self.kind
        return gapic_v1.method_async.wrap_method(func, *args, **kwargs)

    def close(self):
        return self.grpc_channel.close()

    @property
    def kind(self) -> str:
        return "grpc_asyncio"

    @property
    def delete_operation(
        self,
    ) -> Callable[[operations_pb2.DeleteOperationRequest], None]:
        r"""Return a callable for the delete_operation method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_operation" not in self._stubs:
            self._stubs["delete_operation"] = self.grpc_channel.unary_unary(
                "/google.longrunning.Operations/DeleteOperation",
                request_serializer=operations_pb2.DeleteOperationRequest.SerializeToString,
                response_deserializer=None,
            )
        return self._stubs["delete_operation"]

    @property
    def cancel_operation(
        self,
    ) -> Callable[[operations_pb2.CancelOperationRequest], None]:
        r"""Return a callable for the cancel_operation method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "cancel_operation" not in self._stubs:
            self._stubs["cancel_operation"] = self.grpc_channel.unary_unary(
                "/google.longrunning.Operations/CancelOperation",
                request_serializer=operations_pb2.CancelOperationRequest.SerializeToString,
                response_deserializer=None,
            )
        return self._stubs["cancel_operation"]

    @property
    def get_operation(
        self,
    ) -> Callable[[operations_pb2.GetOperationRequest], operations_pb2.Operation]:
        r"""Return a callable for the get_operation method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_operation" not in self._stubs:
            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
                "/google.longrunning.Operations/GetOperation",
                request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["get_operation"]

    @property
    def list_operations(
        self,
    ) -> Callable[
        [operations_pb2.ListOperationsRequest], operations_pb2.ListOperationsResponse
    ]:
        r"""Return a callable for the list_operations method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_operations" not in self._stubs:
            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
                "/google.longrunning.Operations/ListOperations",
                request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
                response_deserializer=operations_pb2.ListOperationsResponse.FromString,
            )
        return self._stubs["list_operations"]

    @property
    def list_locations(
        self,
    ) -> Callable[
        [locations_pb2.ListLocationsRequest], locations_pb2.ListLocationsResponse
    ]:
        r"""Return a callable for the list locations method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_locations" not in self._stubs:
            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
                "/google.cloud.location.Locations/ListLocations",
                request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
                response_deserializer=locations_pb2.ListLocationsResponse.FromString,
            )
        return self._stubs["list_locations"]

    @property
    def get_location(
        self,
    ) -> Callable[[locations_pb2.GetLocationRequest], locations_pb2.Location]:
        r"""Return a callable for the list locations method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_location" not in self._stubs:
            self._stubs["get_location"] = self.grpc_channel.unary_unary(
                "/google.cloud.location.Locations/GetLocation",
                request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
                response_deserializer=locations_pb2.Location.FromString,
            )
        return self._stubs["get_location"]


__all__ = ("GDCHardwareManagementGrpcAsyncIOTransport",)



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.gdchardwaremanagement import gapic_version as package_version

__version__ = package_version.__version__


from google.cloud.gdchardwaremanagement_v1alpha.services.gdc_hardware_management.async_client import (
    GDCHardwareManagementAsyncClient,
)
from google.cloud.gdchardwaremanagement_v1alpha.services.gdc_hardware_management.client import (
    GDCHardwareManagementClient,
)
from google.cloud.gdchardwaremanagement_v1alpha.types.resources import (
    ChangeLogEntry,
    Comment,
    Contact,
    Dimensions,
    Entity,
    Hardware,
    HardwareConfig,
    HardwareGroup,
    HardwareInstallationInfo,
    HardwareLocation,
    HardwarePhysicalInfo,
    Order,
    OrganizationContact,
    PowerSupply,
    RackSpace,
    Site,
    Sku,
    SkuConfig,
    SkuInstance,
    Subnet,
    SubscriptionConfig,
    TimePeriod,
    Zone,
    ZoneNetworkConfig,
)
from google.cloud.gdchardwaremanagement_v1alpha.types.service import (
    CreateCommentRequest,
    CreateHardwareGroupRequest,
    CreateHardwareRequest,
    CreateOrderRequest,
    CreateSiteRequest,
    CreateZoneRequest,
    DeleteHardwareGroupRequest,
    DeleteHardwareRequest,
    DeleteOrderRequest,
    DeleteSiteRequest,
    DeleteZoneRequest,
    GetChangeLogEntryRequest,
    GetCommentRequest,
    GetHardwareGroupRequest,
    GetHardwareRequest,
    GetOrderRequest,
    GetSiteRequest,
    GetSkuRequest,
    GetZoneRequest,
    ListChangeLogEntriesRequest,
    ListChangeLogEntriesResponse,
    ListCommentsRequest,
    ListCommentsResponse,
    ListHardwareGroupsRequest,
    ListHardwareGroupsResponse,
    ListHardwareRequest,
    ListHardwareResponse,
    ListOrdersRequest,
    ListOrdersResponse,
    ListSitesRequest,
    ListSitesResponse,
    ListSkusRequest,
    ListSkusResponse,
    ListZonesRequest,
    ListZonesResponse,
    OperationMetadata,
    RecordActionOnCommentRequest,
    SignalZoneStateRequest,
    SubmitOrderRequest,
    UpdateHardwareGroupRequest,
    UpdateHardwareRequest,
    UpdateOrderRequest,
    UpdateSiteRequest,
    UpdateZoneRequest,
)

__all__ = (
    "GDCHardwareManagementClient",
    "GDCHardwareManagementAsyncClient",
    "ChangeLogEntry",
    "Comment",
    "Contact",
    "Dimensions",
    "Hardware",
    "HardwareConfig",
    "HardwareGroup",
    "HardwareInstallationInfo",
    "HardwareLocation",
    "HardwarePhysicalInfo",
    "Order",
    "OrganizationContact",
    "RackSpace",
    "Site",
    "Sku",
    "SkuConfig",
    "SkuInstance",
    "Subnet",
    "SubscriptionConfig",
    "TimePeriod",
    "Zone",
    "ZoneNetworkConfig",
    "Entity",
    "PowerSupply",
    "CreateCommentRequest",
    "CreateHardwareGroupRequest",
    "CreateHardwareRequest",
    "CreateOrderRequest",
    "CreateSiteRequest",
    "CreateZoneRequest",
    "DeleteHardwareGroupRequest",
    "DeleteHardwareRequest",
    "DeleteOrderRequest",
    "DeleteSiteRequest",
    "DeleteZoneRequest",
    "GetChangeLogEntryRequest",
    "GetCommentRequest",
    "GetHardwareGroupRequest",
    "GetHardwareRequest",
    "GetOrderRequest",
    "GetSiteRequest",
    "GetSkuRequest",
    "GetZoneRequest",
    "ListChangeLogEntriesRequest",
    "ListChangeLogEntriesResponse",
    "ListCommentsRequest",
    "ListCommentsResponse",
    "ListHardwareGroupsRequest",
    "ListHardwareGroupsResponse",
    "ListHardwareRequest",
    "ListHardwareResponse",
    "ListOrdersRequest",
    "ListOrdersResponse",
    "ListSitesRequest",
    "ListSitesResponse",
    "ListSkusRequest",
    "ListSkusResponse",
    "ListZonesRequest",
    "ListZonesResponse",
    "OperationMetadata",
    "RecordActionOnCommentRequest",
    "SignalZoneStateRequest",
    "SubmitOrderRequest",
    "UpdateHardwareGroupRequest",
    "UpdateHardwareRequest",
    "UpdateOrderRequest",
    "UpdateSiteRequest",
    "UpdateZoneRequest",
)



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
from google.type import date_pb2  # type: ignore
from google.type import datetime_pb2  # type: ignore
from google.type import dayofweek_pb2  # type: ignore
from google.type import postal_address_pb2  # type: ignore
from google.type import timeofday_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.gdchardwaremanagement.v1alpha",
    manifest={
        "PowerSupply",
        "Entity",
        "Order",
        "Site",
        "HardwareGroup",
        "Hardware",
        "Comment",
        "ChangeLogEntry",
        "Sku",
        "Zone",
        "OrganizationContact",
        "Contact",
        "HardwareConfig",
        "SkuConfig",
        "SkuInstance",
        "HardwarePhysicalInfo",
        "HardwareInstallationInfo",
        "ZoneNetworkConfig",
        "Subnet",
        "TimePeriod",
        "Dimensions",
        "RackSpace",
        "HardwareLocation",
        "SubscriptionConfig",
    },
)


class PowerSupply(proto.Enum):
    r"""The power supply options.

    Values:
        POWER_SUPPLY_UNSPECIFIED (0):
            Power supply is unspecified.
        POWER_SUPPLY_AC (1):
            AC power supply.
        POWER_SUPPLY_DC (2):
            DC power supply.
    """
    POWER_SUPPLY_UNSPECIFIED = 0
    POWER_SUPPLY_AC = 1
    POWER_SUPPLY_DC = 2


class Entity(proto.Enum):
    r"""Entity is used to denote an organization or party.

    Values:
        ENTITY_UNSPECIFIED (0):
            Entity is unspecified.
        GOOGLE (1):
            Google.
        CUSTOMER (2):
            Customer.
        VENDOR (3):
            Vendor.
    """
    ENTITY_UNSPECIFIED = 0
    GOOGLE = 1
    CUSTOMER = 2
    VENDOR = 3


class Order(proto.Message):
    r"""An order for GDC hardware.

    Attributes:
        name (str):
            Identifier. Name of this order. Format:
            ``projects/{project}/locations/{location}/orders/{order}``
        display_name (str):
            Optional. Display name of this order.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this order was
            created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this order was last
            updated.
        labels (MutableMapping[str, str]):
            Optional. Labels associated with this order as key value
            pairs. For more information about labels, see `Create and
            manage
            labels <https://cloud.google.com/resource-manager/docs/creating-managing-labels>`__.
        state (google.cloud.gdchardwaremanagement_v1alpha.types.Order.State):
            Output only. State of this order. On order
            creation, state will be set to DRAFT.
        organization_contact (google.cloud.gdchardwaremanagement_v1alpha.types.OrganizationContact):
            Required. Customer contact information.
        target_workloads (MutableSequence[str]):
            Optional. Customer specified workloads of
            interest targeted by this order. This must
            contain <= 20 elements and the length of each
            element must be <= 50 characters.
        customer_motivation (str):
            Required. Information about the customer's
            motivation for this order. The length of this
            field must be <= 1000 characters.
        fulfillment_time (google.protobuf.timestamp_pb2.Timestamp):
            Required. Customer specified deadline by when
            this order should be fulfilled.
        region_code (str):
            Required. `Unicode CLDR <http://cldr.unicode.org/>`__ region
            code where this order will be deployed. For a list of valid
            CLDR region codes, see the `Language Subtag
            Registry <https://www.iana.org/assignments/language-subtag-registry/language-subtag-registry>`__.
        order_form_uri (str):
            Output only. Link to the order form.
        type_ (google.cloud.gdchardwaremanagement_v1alpha.types.Order.Type):
            Output only. Type of this Order.
        submit_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when the order was
            submitted. Is auto-populated to the current time
            when an order is submitted.
        billing_id (str):
            Required. The Google Cloud Billing ID to be
            charged for this order.
        existing_hardware (MutableSequence[google.cloud.gdchardwaremanagement_v1alpha.types.HardwareLocation]):
            Optional. Existing hardware to be removed as
            part of this order. Note: any hardware removed
            will be recycled unless otherwise agreed.
    """

    class State(proto.Enum):
        r"""Valid states of an order.

        Values:
            STATE_UNSPECIFIED (0):
                State of the order is unspecified.
            DRAFT (1):
                Order is being drafted by the customer and
                has not been submitted yet.
            SUBMITTED (2):
                Order has been submitted to Google.
            INFO_COMPLETE (12):
                All information required from the customer
                for fulfillment of the order is complete.
            ACCEPTED (3):
                Order has been accepted by Google.
            ADDITIONAL_INFO_NEEDED (4):
                Order needs more information from the
                customer.
            BUILDING (5):
                Google has initiated building hardware for
                the order.
            SHIPPING (6):
                The hardware has been built and is being
                shipped.
            INSTALLING (7):
                The hardware is being installed.
            FAILED (8):
                An error occurred in processing the order and
                customer intervention is required.
            PARTIALLY_COMPLETED (9):
                Order has been partially completed i.e., some
                hardware have been delivered and installed.
            COMPLETED (10):
                Order has been completed.
            CANCELLED (11):
                Order has been cancelled.
        """
        STATE_UNSPECIFIED = 0
        DRAFT = 1
        SUBMITTED = 2
        INFO_COMPLETE = 12
        ACCEPTED = 3
        ADDITIONAL_INFO_NEEDED = 4
        BUILDING = 5
        SHIPPING = 6
        INSTALLING = 7
        FAILED = 8
        PARTIALLY_COMPLETED = 9
        COMPLETED = 10
        CANCELLED = 11

    class Type(proto.Enum):
        r"""Valid types of an Order.

        Values:
            TYPE_UNSPECIFIED (0):
                Type of the order is unspecified.
            PAID (1):
                Paid by the customer.
            POC (2):
                Proof of concept for the customer.
        """
        TYPE_UNSPECIFIED = 0
        PAID = 1
        POC = 2

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=13,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=5,
        enum=State,
    )
    organization_contact: "OrganizationContact" = proto.Field(
        proto.MESSAGE,
        number=6,
        message="OrganizationContact",
    )
    target_workloads: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    customer_motivation: str = proto.Field(
        proto.STRING,
        number=8,
    )
    fulfillment_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=9,
        message=timestamp_pb2.Timestamp,
    )
    region_code: str = proto.Field(
        proto.STRING,
        number=10,
    )
    order_form_uri: str = proto.Field(
        proto.STRING,
        number=11,
    )
    type_: Type = proto.Field(
        proto.ENUM,
        number=12,
        enum=Type,
    )
    submit_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=14,
        message=timestamp_pb2.Timestamp,
    )
    billing_id: str = proto.Field(
        proto.STRING,
        number=15,
    )
    existing_hardware: MutableSequence["HardwareLocation"] = proto.RepeatedField(
        proto.MESSAGE,
        number=16,
        message="HardwareLocation",
    )


class Site(proto.Message):
    r"""A physical site where hardware will be installed.

    Attributes:
        name (str):
            Identifier. Name of the site. Format:
            ``projects/{project}/locations/{location}/sites/{site}``
        display_name (str):
            Optional. Display name of this Site.
        description (str):
            Optional. Description of this Site.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this site was created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this site was last
            updated.
        labels (MutableMapping[str, str]):
            Optional. Labels associated with this site as key value
            pairs. For more information about labels, see `Create and
            manage
            labels <https://cloud.google.com/resource-manager/docs/creating-managing-labels>`__.
        organization_contact (google.cloud.gdchardwaremanagement_v1alpha.types.OrganizationContact):
            Required. Contact information for this site.
        google_maps_pin_uri (str):
            Optional. A URL to the Google Maps address location of the
            site. An example value is ``https://goo.gl/maps/xxxxxxxxx``.
        access_times (MutableSequence[google.cloud.gdchardwaremanagement_v1alpha.types.TimePeriod]):
            Optional. The time periods when the site is
            accessible. If this field is empty, the site is
            accessible at all times.

            This field is used by Google to schedule the
            initial installation as well as any later
            hardware maintenance. You may update this at any
            time. For example, if the initial installation
            is requested during off-hours but maintenance
            should be performed during regular business
            hours, you should update the access times after
            initial installation is complete.
        notes (str):
            Optional. Any additional notes for this Site.
            Please include information about:

            - security or access restrictions
            - any regulations affecting the technicians
              visiting the site
            - any special process or approval required to
              move the equipment
            - whether a representative will be available
              during site visits

        customer_site_id (str):
            Optional. Customer defined identifier for
            this Site. This can be used to identify the site
            in the customer's own systems.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=24,
    )
    description: str = proto.Field(
        proto.STRING,
        number=25,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    organization_contact: "OrganizationContact" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="OrganizationContact",
    )
    google_maps_pin_uri: str = proto.Field(
        proto.STRING,
        number=6,
    )
    access_times: MutableSequence["TimePeriod"] = proto.RepeatedField(
        proto.MESSAGE,
        number=26,
        message="TimePeriod",
    )
    notes: str = proto.Field(
        proto.STRING,
        number=27,
    )
    customer_site_id: str = proto.Field(
        proto.STRING,
        number=28,
    )


class HardwareGroup(proto.Message):
    r"""A group of hardware that is part of the same order, has the
    same SKU, and is delivered to the same site.

    Attributes:
        name (str):
            Identifier. Name of this hardware group. Format:
            ``projects/{project}/locations/{location}/orders/{order}/hardwareGroups/{hardware_group}``
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this hardware group
            was created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this hardware group
            was last updated.
        labels (MutableMapping[str, str]):
            Optional. Labels associated with this hardware group as key
            value pairs. For more information about labels, see `Create
            and manage
            labels <https://cloud.google.com/resource-manager/docs/creating-managing-labels>`__.
        hardware_count (int):
            Required. Number of hardware in this
            HardwareGroup.
        config (google.cloud.gdchardwaremanagement_v1alpha.types.HardwareConfig):
            Required. Configuration for hardware in this
            HardwareGroup.
        site (str):
            Required. Name of the site where the hardware in this
            HardwareGroup will be delivered. Format:
            ``projects/{project}/locations/{location}/sites/{site}``
        state (google.cloud.gdchardwaremanagement_v1alpha.types.HardwareGroup.State):
            Output only. Current state of this
            HardwareGroup.
        zone (str):
            Optional. Name of the zone that the hardware in this
            HardwareGroup belongs to. Format:
            ``projects/{project}/locations/{location}/zones/{zone}``
        requested_installation_date (google.type.date_pb2.Date):
            Optional. Requested installation date for the
            hardware in this HardwareGroup. Filled in by the
            customer.
    """

    class State(proto.Enum):
        r"""Valid states of a HardwareGroup.

        Values:
            STATE_UNSPECIFIED (0):
                State of the HardwareGroup is unspecified.
            ADDITIONAL_INFO_NEEDED (1):
                More information is required from the
                customer to make progress.
            BUILDING (2):
                Google has initiated building hardware for
                this HardwareGroup.
            SHIPPING (3):
                The hardware has been built and is being
                shipped.
            INSTALLING (4):
                The hardware is being installed.
            PARTIALLY_INSTALLED (5):
                Some hardware in the HardwareGroup have been
                installed.
            INSTALLED (6):
                All hardware in the HardwareGroup have been
                installed.
            FAILED (7):
                An error occurred and customer intervention
                is required.
        """
        STATE_UNSPECIFIED = 0
        ADDITIONAL_INFO_NEEDED = 1
        BUILDING = 2
        SHIPPING = 3
        INSTALLING = 4
        PARTIALLY_INSTALLED = 5
        INSTALLED = 6
        FAILED = 7

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    hardware_count: int = proto.Field(
        proto.INT32,
        number=5,
    )
    config: "HardwareConfig" = proto.Field(
        proto.MESSAGE,
        number=6,
        message="HardwareConfig",
    )
    site: str = proto.Field(
        proto.STRING,
        number=7,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=8,
        enum=State,
    )
    zone: str = proto.Field(
        proto.STRING,
        number=9,
    )
    requested_installation_date: date_pb2.Date = proto.Field(
        proto.MESSAGE,
        number=10,
        message=date_pb2.Date,
    )


class Hardware(proto.Message):
    r"""An instance of hardware installed at a site.

    Attributes:
        name (str):
            Identifier. Name of this hardware. Format:
            ``projects/{project}/locations/{location}/hardware/{hardware}``
        display_name (str):
            Optional. Display name for this hardware.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this hardware was
            created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this hardware was last
            updated.
        labels (MutableMapping[str, str]):
            Optional. Labels associated with this hardware as key value
            pairs. For more information about labels, see `Create and
            manage
            labels <https://cloud.google.com/resource-manager/docs/creating-managing-labels>`__.
        order (str):
            Required. Name of the order that this hardware belongs to.
            Format:
            ``projects/{project}/locations/{location}/orders/{order}``
        hardware_group (str):
            Output only. Name for the hardware group that this hardware
            belongs to. Format:
            ``projects/{project}/locations/{location}/orders/{order}/hardwareGroups/{hardware_group}``
        site (str):
            Required. Name for the site that this hardware belongs to.
            Format:
            ``projects/{project}/locations/{location}/sites/{site}``
        state (google.cloud.gdchardwaremanagement_v1alpha.types.Hardware.State):
            Output only. Current state for this hardware.
        ciq_uri (str):
            Output only. Link to the Customer Intake
            Questionnaire (CIQ) sheet for this Hardware.
        config (google.cloud.gdchardwaremanagement_v1alpha.types.HardwareConfig):
            Required. Configuration for this hardware.
        estimated_installation_date (google.type.date_pb2.Date):
            Output only. Estimated installation date for
            this hardware.
        physical_info (google.cloud.gdchardwaremanagement_v1alpha.types.HardwarePhysicalInfo):
            Optional. Physical properties of this
            hardware.
        installation_info (google.cloud.gdchardwaremanagement_v1alpha.types.HardwareInstallationInfo):
            Optional. Information for installation of
            this hardware.
        zone (str):
            Required. Name for the zone that this hardware belongs to.
            Format:
            ``projects/{project}/locations/{location}/zones/{zone}``
        requested_installation_date (google.type.date_pb2.Date):
            Optional. Requested installation date for this hardware. If
            not specified, this is auto-populated from the order's
            fulfillment_time upon submission or from the HardwareGroup's
            requested_installation_date upon order acceptance.
        actual_installation_date (google.type.date_pb2.Date):
            Output only. Actual installation date for
            this hardware. Filled in by Google.
        machine_infos (MutableSequence[google.cloud.gdchardwaremanagement_v1alpha.types.Hardware.MachineInfo]):
            Output only. Per machine asset information
            needed for turnup.
    """

    class State(proto.Enum):
        r"""Valid states for hardware.

        Values:
            STATE_UNSPECIFIED (0):
                State of the Hardware is unspecified.
            ADDITIONAL_INFO_NEEDED (1):
                More information is required from the
                customer to make progress.
            BUILDING (2):
                Google has initiated building hardware for
                this Hardware.
            SHIPPING (3):
                The hardware has been built and is being
                shipped.
            INSTALLING (4):
                The hardware is being installed.
            INSTALLED (5):
                The hardware has been installed.
            FAILED (6):
                An error occurred and customer intervention
                is required.
        """
        STATE_UNSPECIFIED = 0
        ADDITIONAL_INFO_NEEDED = 1
        BUILDING = 2
        SHIPPING = 3
        INSTALLING = 4
        INSTALLED = 5
        FAILED = 6

    class MacAddress(proto.Message):
        r"""Message to describe the MAC address of a machine.

        Attributes:
            address (str):
                Output only. Address string.
            type_ (google.cloud.gdchardwaremanagement_v1alpha.types.Hardware.MacAddress.AddressType):
                Output only. Address type for this MAC
                address.
        """

        class AddressType(proto.Enum):
            r"""Enum for the different types of MAC address.

            Values:
                ADDRESS_TYPE_UNSPECIFIED (0):
                    Unspecified address type.
                NIC (1):
                    Address of a network interface card.
                BMC (2):
                    Address of a baseboard management controller.
                VIRTUAL (3):
                    Address of a virtual interface.
            """
            ADDRESS_TYPE_UNSPECIFIED = 0
            NIC = 1
            BMC = 2
            VIRTUAL = 3

        address: str = proto.Field(
            proto.STRING,
            number=1,
        )
        type_: "Hardware.MacAddress.AddressType" = proto.Field(
            proto.ENUM,
            number=2,
            enum="Hardware.MacAddress.AddressType",
        )

    class DiskInfo(proto.Message):
        r"""Information about individual disks on a machine.

        Attributes:
            manufacturer (str):
                Output only. Disk manufacturer.
            slot (int):
                Output only. Disk slot number.
            serial_number (str):
                Output only. Disk serial number.
            psid (str):
                Output only. Disk PSID.
            part_number (str):
                Output only. Disk part number.
            model_number (str):
                Output only. Disk model number.
        """

        manufacturer: str = proto.Field(
            proto.STRING,
            number=1,
        )
        slot: int = proto.Field(
            proto.INT32,
            number=2,
        )
        serial_number: str = proto.Field(
            proto.STRING,
            number=3,
        )
        psid: str = proto.Field(
            proto.STRING,
            number=4,
        )
        part_number: str = proto.Field(
            proto.STRING,
            number=5,
        )
        model_number: str = proto.Field(
            proto.STRING,
            number=6,
        )

    class MachineInfo(proto.Message):
        r"""Information about individual machines vendors will provide
        during turnup.

        Attributes:
            service_tag (str):
                Output only. Machine service tag.
            mac_addresses (MutableSequence[google.cloud.gdchardwaremanagement_v1alpha.types.Hardware.MacAddress]):
                Output only. Each associated MAC address.
            name (str):
                Output only. Machine name.
            disk_infos (MutableSequence[google.cloud.gdchardwaremanagement_v1alpha.types.Hardware.DiskInfo]):
                Output only. Information for each disk
                installed.
        """

        service_tag: str = proto.Field(
            proto.STRING,
            number=1,
        )
        mac_addresses: MutableSequence["Hardware.MacAddress"] = proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message="Hardware.MacAddress",
        )
        name: str = proto.Field(
            proto.STRING,
            number=3,
        )
        disk_infos: MutableSequence["Hardware.DiskInfo"] = proto.RepeatedField(
            proto.MESSAGE,
            number=4,
            message="Hardware.DiskInfo",
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=5,
    )
    order: str = proto.Field(
        proto.STRING,
        number=6,
    )
    hardware_group: str = proto.Field(
        proto.STRING,
        number=7,
    )
    site: str = proto.Field(
        proto.STRING,
        number=8,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=9,
        enum=State,
    )
    ciq_uri: str = proto.Field(
        proto.STRING,
        number=10,
    )
    config: "HardwareConfig" = proto.Field(
        proto.MESSAGE,
        number=11,
        message="HardwareConfig",
    )
    estimated_installation_date: date_pb2.Date = proto.Field(
        proto.MESSAGE,
        number=12,
        message=date_pb2.Date,
    )
    physical_info: "HardwarePhysicalInfo" = proto.Field(
        proto.MESSAGE,
        number=13,
        message="HardwarePhysicalInfo",
    )
    installation_info: "HardwareInstallationInfo" = proto.Field(
        proto.MESSAGE,
        number=14,
        message="HardwareInstallationInfo",
    )
    zone: str = proto.Field(
        proto.STRING,
        number=15,
    )
    requested_installation_date: date_pb2.Date = proto.Field(
        proto.MESSAGE,
        number=16,
        message=date_pb2.Date,
    )
    actual_installation_date: date_pb2.Date = proto.Field(
        proto.MESSAGE,
        number=17,
        message=date_pb2.Date,
    )
    machine_infos: MutableSequence[MachineInfo] = proto.RepeatedField(
        proto.MESSAGE,
        number=20,
        message=MachineInfo,
    )


class Comment(proto.Message):
    r"""A comment on an order.

    Attributes:
        name (str):
            Identifier. Name of this comment. Format:
            ``projects/{project}/locations/{location}/orders/{order}/comments/{comment}``
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this comment was
            created.
        labels (MutableMapping[str, str]):
            Optional. Labels associated with this comment as key value
            pairs. For more information about labels, see `Create and
            manage
            labels <https://cloud.google.com/resource-manager/docs/creating-managing-labels>`__.
        author (str):
            Output only. Username of the author of this
            comment. This is auto-populated from the
            credentials used during creation of the comment.
        text (str):
            Required. Text of this comment. The length of
            text must be <= 1000 characters.
        customer_viewed_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp of the first time this
            comment was viewed by the customer. If the
            comment wasn't viewed then this timestamp will
            be unset.
        author_entity (google.cloud.gdchardwaremanagement_v1alpha.types.Entity):
            Output only. The entity the author belongs
            to.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=3,
    )
    author: str = proto.Field(
        proto.STRING,
        number=4,
    )
    text: str = proto.Field(
        proto.STRING,
        number=5,
    )
    customer_viewed_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    author_entity: "Entity" = proto.Field(
        proto.ENUM,
        number=7,
        enum="Entity",
    )


class ChangeLogEntry(proto.Message):
    r"""A log entry of a change made to an order.

    Attributes:
        name (str):
            Identifier. Name of this change log entry. Format:
            ``projects/{project}/locations/{location}/orders/{order}/changeLogEntries/{change_log_entry}``
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this change log entry
            was created.
        labels (MutableMapping[str, str]):
            Optional. Labels associated with this change log entry as
            key value pairs. For more information about labels, see
            `Create and manage
            labels <https://cloud.google.com/resource-manager/docs/creating-managing-labels>`__.
        log (str):
            Output only. Content of this log entry.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=3,
    )
    log: str = proto.Field(
        proto.STRING,
        number=4,
    )


class Sku(proto.Message):
    r"""A stock keeping unit (SKU) of GDC hardware.

    Attributes:
        name (str):
            Identifier. Name of this SKU. Format:
            ``projects/{project}/locations/{location}/skus/{sku}``
        display_name (str):
            Output only. Display name of this SKU.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this SKU was created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this SKU was last
            updated.
        config (google.cloud.gdchardwaremanagement_v1alpha.types.SkuConfig):
            Output only. Configuration for this SKU.
        instances (MutableSequence[google.cloud.gdchardwaremanagement_v1alpha.types.SkuInstance]):
            Output only. Available instances of this SKU.
            This field should be used for checking
            availability of a SKU.
        description (str):
            Output only. Description of this SKU.
        revision_id (str):
            Output only. The SKU revision ID. A new revision is created
            whenever ``config`` is updated. The format is an 8-character
            hexadecimal string.
        is_active (bool):
            Output only. Flag to indicate whether or not
            this revision is active. Only an active revision
            can be used in a new Order.
        type_ (google.cloud.gdchardwaremanagement_v1alpha.types.Sku.Type):
            Output only. Type of this SKU.
        vcpu_count (int):
            Output only. The vCPU count associated with
            this SKU.
    """

    class Type(proto.Enum):
        r"""Valid types of a SKU.

        Values:
            TYPE_UNSPECIFIED (0):
                Type of the SKU is unspecified. This is not
                an allowed value.
            RACK (1):
                Rack SKU.
            SERVER (2):
                Server SKU.
        """
        TYPE_UNSPECIFIED = 0
        RACK = 1
        SERVER = 2

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    config: "SkuConfig" = proto.Field(
        proto.MESSAGE,
        number=6,
        message="SkuConfig",
    )
    instances: MutableSequence["SkuInstance"] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message="SkuInstance",
    )
    description: str = proto.Field(
        proto.STRING,
        number=8,
    )
    revision_id: str = proto.Field(
        proto.STRING,
        number=9,
    )
    is_active: bool = proto.Field(
        proto.BOOL,
        number=10,
    )
    type_: Type = proto.Field(
        proto.ENUM,
        number=11,
        enum=Type,
    )
    vcpu_count: int = proto.Field(
        proto.INT32,
        number=12,
    )


class Zone(proto.Message):
    r"""A zone holding a set of hardware.

    Attributes:
        name (str):
            Identifier. Name of this zone. Format:
            ``projects/{project}/locations/{location}/zones/{zone}``
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this zone was created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this zone was last
            updated.
        labels (MutableMapping[str, str]):
            Optional. Labels associated with this zone as key value
            pairs. For more information about labels, see `Create and
            manage
            labels <https://cloud.google.com/resource-manager/docs/creating-managing-labels>`__.
        display_name (str):
            Optional. Human friendly display name of this
            zone.
        state (google.cloud.gdchardwaremanagement_v1alpha.types.Zone.State):
            Output only. Current state for this zone.
        contacts (MutableSequence[google.cloud.gdchardwaremanagement_v1alpha.types.Contact]):
            Required. The points of contact.
        ciq_uri (str):
            Output only. Link to the Customer Intake
            Questionnaire (CIQ) sheet for this zone.
        network_config (google.cloud.gdchardwaremanagement_v1alpha.types.ZoneNetworkConfig):
            Optional. Networking configuration for this
            zone.
        globally_unique_id (str):
            Output only. Globally unique identifier
            generated for this Edge Zone.
        subscription_configs (MutableSequence[google.cloud.gdchardwaremanagement_v1alpha.types.SubscriptionConfig]):
            Output only. Subscription configurations for
            this zone.
    """

    class State(proto.Enum):
        r"""Valid states for a zone.

        Values:
            STATE_UNSPECIFIED (0):
                State of the Zone is unspecified.
            ADDITIONAL_INFO_NEEDED (1):
                More information is required from the
                customer to make progress.
            PREPARING (2):
                Google is preparing the Zone.
            READY_FOR_CUSTOMER_FACTORY_TURNUP_CHECKS (5):
                Factory turnup has succeeded.
            READY_FOR_SITE_TURNUP (6):
                The Zone is ready for site turnup.
            CUSTOMER_FACTORY_TURNUP_CHECKS_FAILED (7):
                The Zone failed in factory turnup checks.
            ACTIVE (3):
                The Zone is available to use.
            CANCELLED (4):
                The Zone has been cancelled.
        """
        STATE_UNSPECIFIED = 0
        ADDITIONAL_INFO_NEEDED = 1
        PREPARING = 2
        READY_FOR_CUSTOMER_FACTORY_TURNUP_CHECKS = 5
        READY_FOR_SITE_TURNUP = 6
        CUSTOMER_FACTORY_TURNUP_CHECKS_FAILED = 7
        ACTIVE = 3
        CANCELLED = 4

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=5,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=8,
        enum=State,
    )
    contacts: MutableSequence["Contact"] = proto.RepeatedField(
        proto.MESSAGE,
        number=9,
        message="Contact",
    )
    ciq_uri: str = proto.Field(
        proto.STRING,
        number=10,
    )
    network_config: "ZoneNetworkConfig" = proto.Field(
        proto.MESSAGE,
        number=11,
        message="ZoneNetworkConfig",
    )
    globally_unique_id: str = proto.Field(
        proto.STRING,
        number=12,
    )
    subscription_configs: MutableSequence["SubscriptionConfig"] = proto.RepeatedField(
        proto.MESSAGE,
        number=13,
        message="SubscriptionConfig",
    )


class OrganizationContact(proto.Message):
    r"""Contact information of the customer organization.

    Attributes:
        address (google.type.postal_address_pb2.PostalAddress):
            Required. The organization's address.
        email (str):
            Optional. The organization's email.
        phone (str):
            Optional. The organization's phone number.
        contacts (MutableSequence[google.cloud.gdchardwaremanagement_v1alpha.types.Contact]):
            Required. The individual points of contact in
            the organization at this location.
    """

    address: postal_address_pb2.PostalAddress = proto.Field(
        proto.MESSAGE,
        number=1,
        message=postal_address_pb2.PostalAddress,
    )
    email: str = proto.Field(
        proto.STRING,
        number=2,
    )
    phone: str = proto.Field(
        proto.STRING,
        number=3,
    )
    contacts: MutableSequence["Contact"] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message="Contact",
    )


class Contact(proto.Message):
    r"""Contact details of a point of contact.

    Attributes:
        given_name (str):
            Required. Given name of the contact.
        family_name (str):
            Optional. Family name of the contact.
        email (str):
            Required. Email of the contact.
        phone (str):
            Required. Phone number of the contact.
        time_zone (google.type.datetime_pb2.TimeZone):
            Optional. Time zone of the contact.
        reachable_times (MutableSequence[google.cloud.gdchardwaremanagement_v1alpha.types.TimePeriod]):
            Optional. The time periods when the contact
            is reachable. If this field is empty, the
            contact is reachable at all times.
    """

    given_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    family_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    email: str = proto.Field(
        proto.STRING,
        number=3,
    )
    phone: str = proto.Field(
        proto.STRING,
        number=4,
    )
    time_zone: datetime_pb2.TimeZone = proto.Field(
        proto.MESSAGE,
        number=5,
        message=datetime_pb2.TimeZone,
    )
    reachable_times: MutableSequence["TimePeriod"] = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message="TimePeriod",
    )


class HardwareConfig(proto.Message):
    r"""Configuration for GDC hardware.

    Attributes:
        sku (str):
            Required. Reference to the SKU for this hardware. This can
            point to a specific SKU revision in the form of
            ``resource_name@revision_id`` as defined in
            `AIP-162 <https://google.aip.dev/162>`__. If no revision_id
            is specified, it refers to the latest revision.
        power_supply (google.cloud.gdchardwaremanagement_v1alpha.types.PowerSupply):
            Required. Power supply type for this
            hardware.
        subscription_duration_months (int):
            Optional. Subscription duration for the
            hardware in months.
    """

    sku: str = proto.Field(
        proto.STRING,
        number=1,
    )
    power_supply: "PowerSupply" = proto.Field(
        proto.ENUM,
        number=2,
        enum="PowerSupply",
    )
    subscription_duration_months: int = proto.Field(
        proto.INT32,
        number=3,
    )


class SkuConfig(proto.Message):
    r"""Configuration for a SKU.

    Attributes:
        cpu (str):
            Information about CPU configuration.
        gpu (str):
            Information about GPU configuration.
        ram (str):
            Information about RAM configuration.
        storage (str):
            Information about storage configuration.
    """

    cpu: str = proto.Field(
        proto.STRING,
        number=1,
    )
    gpu: str = proto.Field(
        proto.STRING,
        number=2,
    )
    ram: str = proto.Field(
        proto.STRING,
        number=3,
    )
    storage: str = proto.Field(
        proto.STRING,
        number=4,
    )


class SkuInstance(proto.Message):
    r"""A specific instance of the SKU.

    Attributes:
        region_code (str):
            The `Unicode CLDR <https://cldr.unicode.org>`__ region code
            where this instance is available.
        power_supply (google.cloud.gdchardwaremanagement_v1alpha.types.PowerSupply):
            Power supply type for this instance.
        billing_sku (str):
            Reference to the corresponding SKU in the Cloud Billing API.
            The estimated price information can be retrieved using that
            API. Format: ``services/{service}/skus/{sku}``
        billing_sku_per_vcpu (str):
            Reference to the corresponding SKU per vCPU in the Cloud
            Billing API. The estimated price information can be
            retrieved using that API. Format:
            ``services/{service}/skus/{sku}``
        subscription_duration_months (int):
            Subscription duration for the hardware in
            months.
    """

    region_code: str = proto.Field(
        proto.STRING,
        number=1,
    )
    power_supply: "PowerSupply" = proto.Field(
        proto.ENUM,
        number=2,
        enum="PowerSupply",
    )
    billing_sku: str = proto.Field(
        proto.STRING,
        number=3,
    )
    billing_sku_per_vcpu: str = proto.Field(
        proto.STRING,
        number=4,
    )
    subscription_duration_months: int = proto.Field(
        proto.INT32,
        number=5,
    )


class HardwarePhysicalInfo(proto.Message):
    r"""Physical properties of a hardware.

    Attributes:
        power_receptacle (google.cloud.gdchardwaremanagement_v1alpha.types.HardwarePhysicalInfo.PowerReceptacleType):
            Required. The power receptacle type.
        network_uplink (google.cloud.gdchardwaremanagement_v1alpha.types.HardwarePhysicalInfo.NetworkUplinkType):
            Required. Type of the uplink network
            connection.
        voltage (google.cloud.gdchardwaremanagement_v1alpha.types.HardwarePhysicalInfo.Voltage):
            Required. Voltage of the power supply.
        amperes (google.cloud.gdchardwaremanagement_v1alpha.types.HardwarePhysicalInfo.Amperes):
            Required. Amperes of the power supply.
    """

    class PowerReceptacleType(proto.Enum):
        r"""Valid power receptacle types.

        Values:
            POWER_RECEPTACLE_TYPE_UNSPECIFIED (0):
                Facility plug type is unspecified.
            NEMA_5_15 (1):
                NEMA 5-15.
            C_13 (2):
                C13.
            STANDARD_EU (3):
                Standard european receptacle.
        """
        POWER_RECEPTACLE_TYPE_UNSPECIFIED = 0
        NEMA_5_15 = 1
        C_13 = 2
        STANDARD_EU = 3

    class NetworkUplinkType(proto.Enum):
        r"""Valid network uplink types.

        Values:
            NETWORK_UPLINK_TYPE_UNSPECIFIED (0):
                Network uplink type is unspecified.
            RJ_45 (1):
                RJ-45.
        """
        NETWORK_UPLINK_TYPE_UNSPECIFIED = 0
        RJ_45 = 1

    class Voltage(proto.Enum):
        r"""Valid voltage values.

        Values:
            VOLTAGE_UNSPECIFIED (0):
                Voltage is unspecified.
            VOLTAGE_110 (1):
                120V.
            VOLTAGE_220 (3):
                220V.
        """
        VOLTAGE_UNSPECIFIED = 0
        VOLTAGE_110 = 1
        VOLTAGE_220 = 3

    class Amperes(proto.Enum):
        r"""Valid amperes values.

        Values:
            AMPERES_UNSPECIFIED (0):
                Amperes is unspecified.
            AMPERES_15 (1):
                15A.
        """
        AMPERES_UNSPECIFIED = 0
        AMPERES_15 = 1

    power_receptacle: PowerReceptacleType = proto.Field(
        proto.ENUM,
        number=1,
        enum=PowerReceptacleType,
    )
    network_uplink: NetworkUplinkType = proto.Field(
        proto.ENUM,
        number=2,
        enum=NetworkUplinkType,
    )
    voltage: Voltage = proto.Field(
        proto.ENUM,
        number=3,
        enum=Voltage,
    )
    amperes: Amperes = proto.Field(
        proto.ENUM,
        number=4,
        enum=Amperes,
    )


class HardwareInstallationInfo(proto.Message):
    r"""Information for installation of a Hardware.

    Attributes:
        rack_location (str):
            Required. Location of the rack in the site
            e.g. Floor 2, Room 201, Row 7, Rack 3.
        power_distance_meters (int):
            Required. Distance from the power outlet in
            meters.
        switch_distance_meters (int):
            Required. Distance from the network switch in
            meters.
        rack_unit_dimensions (google.cloud.gdchardwaremanagement_v1alpha.types.Dimensions):
            Required. Dimensions of the rack unit.
        rack_space (google.cloud.gdchardwaremanagement_v1alpha.types.RackSpace):
            Required. Rack space allocated for the
            hardware.
        rack_type (google.cloud.gdchardwaremanagement_v1alpha.types.HardwareInstallationInfo.RackType):
            Required. Type of the rack.
    """

    class RackType(proto.Enum):
        r"""Valid rack types.

        Values:
            RACK_TYPE_UNSPECIFIED (0):
                Rack type is unspecified.
            TWO_POST (1):
                Two post rack.
            FOUR_POST (2):
                Four post rack.
        """
        RACK_TYPE_UNSPECIFIED = 0
        TWO_POST = 1
        FOUR_POST = 2

    rack_location: str = proto.Field(
        proto.STRING,
        number=1,
    )
    power_distance_meters: int = proto.Field(
        proto.INT32,
        number=2,
    )
    switch_distance_meters: int = proto.Field(
        proto.INT32,
        number=3,
    )
    rack_unit_dimensions: "Dimensions" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="Dimensions",
    )
    rack_space: "RackSpace" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="RackSpace",
    )
    rack_type: RackType = proto.Field(
        proto.ENUM,
        number=6,
        enum=RackType,
    )


class ZoneNetworkConfig(proto.Message):
    r"""Networking configuration for a zone.

    Attributes:
        machine_mgmt_ipv4_range (str):
            Required. An IPv4 address block for machine management.
            Should be a private RFC1918 or public CIDR block large
            enough to allocate at least one address per machine in the
            Zone. Should be in ``management_ipv4_subnet``, and disjoint
            with other address ranges.
        kubernetes_node_ipv4_range (str):
            Required. An IPv4 address block for kubernetes nodes. Should
            be a private RFC1918 or public CIDR block large enough to
            allocate at least one address per machine in the Zone.
            Should be in ``kubernetes_ipv4_subnet``, and disjoint with
            other address ranges.
        kubernetes_control_plane_ipv4_range (str):
            Required. An IPv4 address block for kubernetes control
            plane. Should be a private RFC1918 or public CIDR block
            large enough to allocate at least one address per cluster in
            the Zone. Should be in ``kubernetes_ipv4_subnet``, and
            disjoint with other address ranges.
        management_ipv4_subnet (google.cloud.gdchardwaremanagement_v1alpha.types.Subnet):
            Required. An IPv4 subnet for the management
            network.
        kubernetes_ipv4_subnet (google.cloud.gdchardwaremanagement_v1alpha.types.Subnet):
            Optional. An IPv4 subnet for the kubernetes
            network. If unspecified, the kubernetes subnet
            will be the same as the management subnet.
    """

    machine_mgmt_ipv4_range: str = proto.Field(
        proto.STRING,
        number=1,
    )
    kubernetes_node_ipv4_range: str = proto.Field(
        proto.STRING,
        number=2,
    )
    kubernetes_control_plane_ipv4_range: str = proto.Field(
        proto.STRING,
        number=3,
    )
    management_ipv4_subnet: "Subnet" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="Subnet",
    )
    kubernetes_ipv4_subnet: "Subnet" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="Subnet",
    )


class Subnet(proto.Message):
    r"""Represents a subnet.

    Attributes:
        address_range (str):
            Required. Address range for this subnet in
            CIDR notation.
        default_gateway_ip_address (str):
            Required. Default gateway for this subnet.
    """

    address_range: str = proto.Field(
        proto.STRING,
        number=1,
    )
    default_gateway_ip_address: str = proto.Field(
        proto.STRING,
        number=2,
    )


class TimePeriod(proto.Message):
    r"""Represents a time period in a week.

    Attributes:
        start_time (google.type.timeofday_pb2.TimeOfDay):
            Required. The start of the time period.
        end_time (google.type.timeofday_pb2.TimeOfDay):
            Required. The end of the time period.
        days (MutableSequence[google.type.dayofweek_pb2.DayOfWeek]):
            Required. The days of the week that the time
            period is active.
    """

    start_time: timeofday_pb2.TimeOfDay = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timeofday_pb2.TimeOfDay,
    )
    end_time: timeofday_pb2.TimeOfDay = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timeofday_pb2.TimeOfDay,
    )
    days: MutableSequence[dayofweek_pb2.DayOfWeek] = proto.RepeatedField(
        proto.ENUM,
        number=3,
        enum=dayofweek_pb2.DayOfWeek,
    )


class Dimensions(proto.Message):
    r"""Represents the dimensions of an object.

    Attributes:
        width_inches (float):
            Required. Width in inches.
        height_inches (float):
            Required. Height in inches.
        depth_inches (float):
            Required. Depth in inches.
    """

    width_inches: float = proto.Field(
        proto.FLOAT,
        number=1,
    )
    height_inches: float = proto.Field(
        proto.FLOAT,
        number=2,
    )
    depth_inches: float = proto.Field(
        proto.FLOAT,
        number=3,
    )


class RackSpace(proto.Message):
    r"""Represents contiguous space in a rack.

    Attributes:
        start_rack_unit (int):
            Required. First rack unit of the rack space
            (inclusive).
        end_rack_unit (int):
            Required. Last rack unit of the rack space
            (inclusive).
    """

    start_rack_unit: int = proto.Field(
        proto.INT32,
        number=1,
    )
    end_rack_unit: int = proto.Field(
        proto.INT32,
        number=2,
    )


class HardwareLocation(proto.Message):
    r"""Represents the location of one or many hardware.

    Attributes:
        site (str):
            Required. Name of the site where the hardware are present.
            Format:
            ``projects/{project}/locations/{location}/sites/{site}``
        rack_location (str):
            Required. Location of the rack in the site
            e.g. Floor 2, Room 201, Row 7, Rack 3.
        rack_space (MutableSequence[google.cloud.gdchardwaremanagement_v1alpha.types.RackSpace]):
            Optional. Spaces occupied by the hardware in
            the rack. If unset, this location is assumed to
            be the entire rack.
    """

    site: str = proto.Field(
        proto.STRING,
        number=1,
    )
    rack_location: str = proto.Field(
        proto.STRING,
        number=2,
    )
    rack_space: MutableSequence["RackSpace"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="RackSpace",
    )


class SubscriptionConfig(proto.Message):
    r"""A message to store a subscription configuration.

    Attributes:
        subscription_id (str):
            Output only. The unique identifier of the
            subscription.
        billing_id (str):
            Output only. The Google Cloud Billing ID that
            the subscription is created under.
        state (google.cloud.gdchardwaremanagement_v1alpha.types.SubscriptionConfig.SubscriptionState):
            Output only. The current state of the
            subscription.
    """

    class SubscriptionState(proto.Enum):
        r"""Enum to represent the state of the subscription.

        Values:
            SUBSCRIPTION_STATE_UNSPECIFIED (0):
                State is unspecified.
            ACTIVE (1):
                Active state means that the subscription has
                been created successfully and billing is
                happening.
            INACTIVE (2):
                Inactive means that the subscription has been
                created successfully, but billing has not
                started yet.
            ERROR (3):
                The subscription is in an erroneous state.
            FAILED_TO_RETRIEVE (4):
                The subscription state failed to be
                retrieved. This may be a transient issue. The
                user should retry the request.
            COMPLETED (5):
                The subscription has been completed, because
                it has reached the end date.
        """
        SUBSCRIPTION_STATE_UNSPECIFIED = 0
        ACTIVE = 1
        INACTIVE = 2
        ERROR = 3
        FAILED_TO_RETRIEVE = 4
        COMPLETED = 5

    subscription_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    billing_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    state: SubscriptionState = proto.Field(
        proto.ENUM,
        number=3,
        enum=SubscriptionState,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
